<?php

class TinkoffController extends Controller
{

    public function actionForm ()
    {
        $tinkoffID = trim (Settings::item('payTinkoffID'));
        $tinkoffKey = trim (Settings::item('payTinkoffKey'));

        $api = new TinkoffMerchantAPI(
            $tinkoffID,  //Ваш Terminal_Key
            $tinkoffKey   //Ваш Secret_Key
        );


        header ("Content-type: text/html; charset=utf-8");
        if (!$_POST)
        {
            die ('Неизвестная ошибка, вернитесь обратно и нажмите, пожалуйста, ещё раз кнопку Продолжить оплату');            
        }
        
        if (!isset($_POST['bill_id']))
        {
            die ('Неизвестная ошибка, вернитесь обратно и нажмите, пожалуйста, ещё раз кнопку Продолжить оплату');            
        } 

        $bill_id = (int) $_POST['bill_id'];

        $b = Bill::model()->findByPk ($bill_id);
        
        //Если не найден - ошибка
        if (!$b)
        {
            die ('Невозможно найти счёт. Вернитесь, пожалуйста, обратно или начните процесс заказа заново.');            
        }

        $ceny = Valuta::conv($b->sum, $b->valuta, $b->usdkurs, $b->eurkurs, $b->uahkurs);     
        $bu = Y::bu();
        $rur = $ceny['rur']*100;  
        $params = [
            'OrderId' => $bill_id,
            'Amount'  => $rur,
            'DATA'    => [
                'Email'           => $b->email
            ],
        ];

        $api->init($params);

        if ($api->error) { echo $api->error; } else {
        echo '<script>
                document.location.href="'.$api->paymentUrl.'"
            </script>';
        }
    }
    
    public function actionIndex ()
    {     

    	if (!Settings::item('payTinkoffOn')) {
            die ('Error: способ отключен');
        }

        $tinkoffID = trim (Settings::item('payTinkoffID'));
        $tinkoffKey = trim (Settings::item('payTinkoffKey'));


        $request = (array)json_decode(file_get_contents('php://input'));
	    header("HTTP/1.1 200 ok");
	    $request['Password'] = $tinkoffKey;
	    ksort($request);
	    $request_str = json_encode($request);
	    $original_token = $request['Token'];
	    unset($request['Token']);

	    $request['Success'] = $request['Success'] === true ? 'true' : 'false';

	    $values = '';
	    foreach ($request as $key => $val) {
	        $values .= $val;
	    }

	    $token = hash('sha256', $values);

	    if ($token == $original_token) {
	    	$bill_id = (int)$request['OrderId']; //Номер счёта	    	
	    	$sum = (int)$request['Amount']/100; //Номер счёта
	       	
	       	if($request['Status']=="CONFIRMED")
	       	{
	       		$way = 'Тинькофф';
        		$type = 'rur'; //Рубли
        		Bill::payBill($bill_id, $way, $sum, $type);
	       	}   
	       	die('OK');
	        
	    } else {
	        die('NOTOK');
	    }

    }

    public function actionOk ()
    {
        $this->redirect (Y::bu().'f/ok/w/yandex');
    }

    public function actionFail ()
    {
        $this->redirect (Y::bu().'f/fail/w/yandex');
    }
}


class TinkoffMerchantAPI
{
    private $api_url;
    private $terminalKey;
    private $secretKey;
    private $paymentId;
    private $status;
    private $error;
    private $response;
    private $paymentUrl;


    public function __construct($terminalKey, $secretKey)
    {
        $this->api_url = 'https://securepay.tinkoff.ru/v2/';
        $this->terminalKey = $terminalKey;
        $this->secretKey = $secretKey;
    }

    public function __get($name)
    {
        switch ($name) {
            case 'paymentId':
                return $this->paymentId;
            case 'status':
                return $this->status;
            case 'error':
                return $this->error;
            case 'paymentUrl':
                return $this->paymentUrl;
            case 'response':
                return htmlentities($this->response);
            default:
                if ($this->response) {
                    if ($json = json_decode($this->response, true)) {
                        foreach ($json as $key => $value) {
                            if (strtolower($name) == strtolower($key)) {
                                return $json[$key];
                            }
                        }
                    }
                }

                return false;
        }
    }

    /**
     * @param $args mixed You could use associative array or url params string
     * @return bool
     * @throws HttpException
     */
    public function init($args)
    {
        return $this->buildQuery('Init', $args);
    }


    public function getState($args)
    {
        return $this->buildQuery('GetState', $args);
    }

    public function confirm($args)
    {
        return $this->buildQuery('Confirm', $args);
    }

    public function charge($args)
    {
        return $this->buildQuery('Charge', $args);
    }

    public function addCustomer($args)
    {
        return $this->buildQuery('AddCustomer', $args);
    }

    public function getCustomer($args)
    {
        return $this->buildQuery('GetCustomer', $args);
    }

    public function removeCustomer($args)
    {
        return $this->buildQuery('RemoveCustomer', $args);
    }

    public function getCardList($args)
    {
        return $this->buildQuery('GetCardList', $args);
    }

    public function removeCard($args)
    {
        return $this->buildQuery('RemoveCard', $args);
    }

    /**
     * Builds a query string and call sendRequest method.
     * Could be used to custom API call method.
     *
     * @param string $path API method name
     * @param mixed $args query params
     *
     * @return mixed
     * @throws HttpException
     */
    public function buildQuery($path, $args)
    {
        $url = $this->api_url;
        if (is_array($args)) {
            if (!array_key_exists('TerminalKey', $args)) {
                $args['TerminalKey'] = $this->terminalKey;
            }
            if (!array_key_exists('Token', $args)) {
                $args['Token'] = $this->_genToken($args);
            }
        }
        $url = $this->_combineUrl($url, $path);


        return $this->_sendRequest($url, $args);
    }

    /**
     * Generates Token
     *
     * @param $args
     * @return string
     */
    private function _genToken($args)
    {
        $token = '';
        $args['Password'] = $this->secretKey;
        ksort($args);

        foreach ($args as $arg) {
            if (!is_array($arg)) {
                $token .= $arg;
            }
        }
        $token = hash('sha256', $token);

        return $token;
    }

    /**
     * Combines parts of URL. Simply gets all parameters and puts '/' between
     *
     * @return string
     */
    private function _combineUrl()
    {
        $args = func_get_args();
        $url = '';
        foreach ($args as $arg) {
            if (is_string($arg)) {
                if ($arg[strlen($arg) - 1] !== '/') $arg .= '/';
                $url .= $arg;
            } else {
                continue;
            }
        }

        return $url;
    }

    /**
     * Main method. Call API with params
     *
     * @param $api_url
     * @param $args
     * @return bool|string
     * @throws HttpException
     */
    private function _sendRequest($api_url, $args)
    {
        $this->error = '';
        if (is_array($args)) {
            $args = json_encode($args);
        }

        if ($curl = curl_init()) {
            curl_setopt($curl, CURLOPT_URL, $api_url);
            curl_setopt($curl, CURLOPT_FOLLOWLOCATION, true);
            curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
            curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, false);
            curl_setopt($curl, CURLOPT_POST, true);
            curl_setopt($curl, CURLOPT_POSTFIELDS, $args);
            curl_setopt($curl, CURLOPT_HTTPHEADER, array(
                'Content-Type: application/json',
            ));

            $out = curl_exec($curl);
            $this->response = $out;
            $json = json_decode($out);

            if ($json) {
                if (@$json->ErrorCode !== "0") {
                    $this->error = @$json->Details;
                } else {
                    $this->paymentUrl = @$json->PaymentURL;
                    $this->paymentId = @$json->PaymentId;
                    $this->status = @$json->Status;
                }
            }

            curl_close($curl);

            return $out;

        } else {
            throw new HttpException('Can not create connection to ' . $api_url . ' with args ' . $args, 404);
        }
    }
}